@@ -120,7 +120,6 @@ EXCLUDE = (
     "cmd/tools/tred.c",
     "cmd/tools/unflatten.c",
     "contrib/diffimg/diffimg.c",
-    "contrib/pangotest/pangotest.c",
     "contrib/prune/prune.c",
     "doc/libgraph/agmemread.c",
     "doc/libgraph/sccmap.c",
@@ -520,8 +519,6 @@ EXCLUDE = (
     "lib/sfdpgen/spring_electrical.h",
     "lib/sfdpgen/stress_model.c",
     "lib/sfdpgen/stress_model.h",
-    "lib/sfdpgen/uniform_stress.c",
-    "lib/sfdpgen/uniform_stress.h",
     "lib/sfio/Sfio_f/_sffileno.c",
     "lib/sfio/Sfio_f/_sfgetc.c",
     "lib/sfio/Sfio_f/_sfputc.c",
