@@ -30,6 +30,7 @@
 
 #include	<common/const.h>
 #include <cgraph/alloc.h>
+#include <cgraph/list.h>
 #include <cgraph/strcasecmp.h>
 #include <cgraph/strview.h>
 
@@ -383,6 +384,8 @@ char *gvplugin_list(GVC_t * gvc, api_t api, const char *str)
     return bp;
 }
 
+DEFINE_LIST(strs, char*)
+
 /* gvPluginList:
  * Return list of plugins of type kind.
  * The size of the list is stored in sz.
@@ -396,10 +399,9 @@ char *gvplugin_list(GVC_t * gvc, api_t api, const char *str)
  */
 char **gvPluginList(GVC_t * gvc, const char *kind, int *sz, const char *str)
 {
-    int api;
+    size_t api;
     const gvplugin_available_t *pnext, *plugin;
-    int cnt = 0;
-    char **list = NULL;
+    strs_t list = {0};
 
     (void)str;
 
@@ -421,14 +423,13 @@ char **gvPluginList(GVC_t * gvc, const char *kind, int *sz, const char *str)
         /* list only one instance of type */
         strview_t q = strview(pnext->typestr, ':');
         if (!typestr_last.data || !strview_case_eq(typestr_last, q)) {
-            list = RALLOC(cnt + 1, list, char *);
-            list[cnt++] = strview_str(q);
+            strs_append(&list, strview_str(q));
         }
         typestr_last = q;
     }
 
-    *sz = cnt;
-    return list;
+    *sz = (int)strs_size(&list);
+    return strs_detach(&list);
 }
 
 void gvplugin_write_status(GVC_t * gvc)
@@ -447,7 +448,7 @@ void gvplugin_write_status(GVC_t * gvc)
     }
 #endif
 
-    for (api = 0; api < ARRAY_SIZE(api_names); api++) {
+    for (api = 0; api < (int)ARRAY_SIZE(api_names); api++) {
         if (gvc->common.verbose >= 2)
             fprintf(stderr, "    %s\t: %s\n", api_names[api], gvplugin_list(gvc, api, ":"));
         else
@@ -465,7 +466,7 @@ Agraph_t *gvplugin_graph(GVC_t * gvc)
     gvplugin_package_t *package;
     const gvplugin_available_t *pnext;
     char bufa[100], *buf1, *buf2, bufb[100], *p, *q, *lq, *t;
-    int api, neededge_loadimage, neededge_device;
+    int neededge_loadimage, neededge_device;
 
     g = agopen("G", Agdirected, NULL);
     agattr(g, AGRAPH, "label", "");
@@ -498,7 +499,7 @@ Agraph_t *gvplugin_graph(GVC_t * gvc)
         strcpy(bufa, package->name);
         strcat(bufa, "_");
         buf1 = bufa + strlen(bufa);
-        for (api = 0; api < ARRAY_SIZE(api_names); api++) {
+        for (size_t api = 0; api < ARRAY_SIZE(api_names); api++) {
             strcpy(buf1, api_names[api]);
             ssg = agsubg(sg, bufa, 1);
             a = agfindgraphattr(ssg, "rank");
@@ -677,7 +678,7 @@ Agraph_t *gvplugin_graph(GVC_t * gvc)
         strcpy(bufa, package->name);
         strcat(bufa, "_");
         buf1 = bufa + strlen(bufa);
-        for (api = 0; api < ARRAY_SIZE(api_names); api++) {
+        for (size_t api = 0; api < ARRAY_SIZE(api_names); api++) {
             strcpy(buf1, api_names[api]);
             strcat(buf1, "_");
             buf2 = bufa + strlen(bufa);
